@@ -170,30 +170,30 @@ class Logistic : public IUnivLaw<Real>
 #ifdef IS_RTKPP_LIB
 
 inline Real Logistic::rand() const
-{ GetRNGstate(); Real s = ::Rf_rlogis(mu_, scale_);
+{ GetRNGstate(); Real s = Rf_rlogis(mu_, scale_);
   PutRNGstate(); return s;
 }
 inline Real Logistic::pdf( Real const& x) const
-{ return ::Rf_dlogis(x, mu_, scale_, false);}
+{ return Rf_dlogis(x, mu_, scale_, false);}
 inline Real Logistic::lpdf( Real const& x) const
-{ return ::Rf_dlogis(x, mu_, scale_, true);}
+{ return Rf_dlogis(x, mu_, scale_, true);}
 inline Real Logistic::cdf( Real const& t) const
-{ return ::Rf_plogis(t, mu_, scale_, true, false);}
+{ return Rf_plogis(t, mu_, scale_, true, false);}
 inline Real Logistic::icdf( Real const& p) const
-{ return ::Rf_qlogis(p, mu_, scale_, true, false);}
+{ return Rf_qlogis(p, mu_, scale_, true, false);}
 
 inline Real Logistic::rand( Real const& mu, Real const& scale)
-{ GetRNGstate(); Real s = ::Rf_rlogis(mu, scale);
+{ GetRNGstate(); Real s = Rf_rlogis(mu, scale);
   PutRNGstate(); return s;
 }
 inline Real Logistic::pdf( Real const& x, Real const& mu, Real const& scale)
-{ return ::Rf_dlogis(x, mu, scale, false);}
+{ return Rf_dlogis(x, mu, scale, false);}
 inline Real Logistic::lpdf( Real const& x, Real const& mu, Real const& scale)
-{ return ::Rf_dlogis(x, mu, scale, true);}
+{ return Rf_dlogis(x, mu, scale, true);}
 inline Real Logistic::cdf( Real const& t, Real const& mu, Real const& scale)
-{ return ::Rf_plogis(t, mu, scale, true, false);}
+{ return Rf_plogis(t, mu, scale, true, false);}
 inline Real Logistic::icdf( Real const& p, Real const& mu, Real const& scale)
-{ return ::Rf_qlogis(p, mu, scale, true, false);}
+{ return Rf_qlogis(p, mu, scale, true, false);}
 
 #endif
 
